smartcard.wx.CardAndReaderTreePanel.BaseCardTreeCtrl

# ``smartcard`.`wx`.`CardAndReaderTreePanel`.`BaseCardTreeCtrl``

class documentation

`class BaseCardTreeCtrl(wx.TreeCtrl):`

Known subclasses: `smartcard.wx.CardAndReaderTreePanel.CardTreeCtrl`, `smartcard.wx.CardAndReaderTreePanel.ReaderTreeCtrl`

View In Hierarchy

Base class for the smart card and reader tree controls.

Method | `__init__` | Constructor. Initializes a smartcard or reader tree control.
Method | `Repaint` | Undocumented
Instance Variable | `capindex` | Undocumented
Instance Variable | `cardimageindex` | Undocumented
Instance Variable | `clientpanel` | Undocumented
Instance Variable | `fldrindex` | Undocumented
Instance Variable | `fldropenindex` | Undocumented
Instance Variable | `il` | Undocumented
Instance Variable | `parent` | Undocumented
Instance Variable | `readerimageindex` | Undocumented

def __init__(self, parent, ID=wx.NewId(), pos=wx.DefaultPosition, size=wx.DefaultSize, style=0, clientpanel=None):
overridden in `smartcard.wx.CardAndReaderTreePanel.CardTreeCtrl`, `smartcard.wx.CardAndReaderTreePanel.ReaderTreeCtrl`

Constructor. Initializes a smartcard or reader tree control.

def Repaint(self):

Undocumented

capindex =

Undocumented

cardimageindex =

Undocumented

clientpanel =

Undocumented

fldrindex =

Undocumented

fldropenindex =

Undocumented

il =

Undocumented

parent =

Undocumented

readerimageindex =

Undocumented